@@ -38,6 +38,7 @@ else:
     import cPickle
     import fcntl
     import select
+    import qm.sigmask
     
 ########################################################################
 # Classes
@@ -132,6 +133,30 @@ class Executable(object):
             # string as the command line, rather than an array of
             # arguments.
             command_line = self.__CreateCommandLine(arguments)
+
+            # Windows supports wide-characters in the environment, but
+            # the Win32 extensions to Python require that all of the
+            # entries in the environment be of the same type,
+            # i.e,. that either all of them be of type StringType or
+            # of type UnicodeType.  Therefore, if we find any elements
+            # that are Unicode strings, convert all of them to Unicode
+            # strings.
+            if environment is not None:
+                # See if there any Unicode strings in the environment.
+                uses_unicode = 0
+                for (k, v) in environment.iteritems():
+                    if (isinstance(k, unicode)
+                        or isinstance(v, unicode)):
+                        uses_unicode = 1
+                        break
+                # If there are Unicode strings in the environment,
+                # convert all of the key-value pairs to Unicode.
+                if uses_unicode:
+                    new_environment = {}
+                    for (k, v) in environment.iteritems():
+                        new_environment[unicode(k)] = unicode(v)
+                    environment = new_environment
+                        
             # Create the child process.
             self.__child \
                 = win32process.CreateProcess(path,
@@ -305,6 +330,16 @@ class Executable(object):
 
         assert sys.platform != "win32"
 
+        # The way Python's threading support works, every thread except
+        # the main thread always has all signals blocked.  This is fine
+        # for the threads themselves, but it causes problems if we
+        # 'fork' from a child thread; the new process starts with all
+        # signals blocked, which is probably not what you want!
+        # Arguably this is a bug in Python, but for the meantime, work
+        # around this by setting the new process's signal mask to match
+        # the signal mask that QMTest was started with.
+        qm.sigmask.restore_mask()
+
         if self.__dir:
             os.chdir(self.__dir)
 
