@@ -137,6 +137,13 @@ class ExecTestBase(Test):
         environment = os.environ.copy()
         # Copy context variables into the environment.
         for key, value in context.items():
+            # If the value has unicode type, only transfer
+            # it if it can be cast to str.
+            if  isinstance(value, unicode):
+                try:
+                    value = str(value)
+                except UnicodeEncodeError:
+                    continue
             if  isinstance(value, str):
                 name = "QMV_" + key.replace(".", "__")
                 environment[name] = value
@@ -154,6 +161,33 @@ class ExecTestBase(Test):
         return environment
 
 
+    def ValidateOutput(self, stdout, stderr, result):
+        """Validate the output of the program.
+
+        'stdout' -- A string containing the data written to the standard output
+        stream.
+
+        'stderr' -- A string containing the data written to the standard error
+        stream.
+
+        'result' -- A 'Result' object. It may be used to annotate
+        the outcome according to the content of stderr.
+
+        returns -- A list of strings giving causes of failure."""
+
+        causes = []
+        # Check to see if the standard output matches.
+        if not self.__CompareText(stdout, self.stdout):
+            causes.append("standard output") 
+            result["ExecTest.expected_stdout"] = result.Quote(self.stdout)
+        # Check to see if the standard error matches.
+        if not self.__CompareText(stderr, self.stderr):
+            causes.append("standard error")
+            result["ExecTest.expected_stderr"] = result.Quote(self.stderr)
+
+        return causes
+
+
     def RunProgram(self, program, arguments, context, result):
         """Run the 'program'.
 
@@ -210,16 +244,8 @@ class ExecTestBase(Test):
                 causes.append("exit_code")
                 result["ExecTest.expected_exit_code"] \
                     = str(self.exit_code)
-            # Check to see if the standard output matches.
-            if not self.__CompareText(stdout, self.stdout):
-                causes.append("standard output")
-                result["ExecTest.expected_stdout"] \
-                    = result.Quote(self.stdout)
-            # Check to see that the standard error matches.
-            if not self.__CompareText(stderr, self.stderr):
-                causes.append("standard error")
-                result["ExecTest.expected_stderr"] \
-                    = result.Quote(self.stderr)
+            # Validate the output.
+            causes += self.ValidateOutput(stdout, stderr, result)
             # If anything went wrong, the test failed.
             if causes:
                 result.Fail("Unexpected %s." % string.join(causes, ", ")) 
@@ -254,7 +280,6 @@ class ExecTestBase(Test):
         # The "splitlines" method works independently of the line ending
         # convention in use.
         return s1.splitlines() == s2.splitlines()
-
         
     
 class ExecTest(ExecTestBase):
