@@ -24,10 +24,12 @@ import qm
 import qm.attachment
 import qm.cmdline
 import qm.platform
+from   qm.test import test
 from   qm.test.result import Result
 from   qm.test.context import *
 from   qm.test.execution_engine import *
 from   qm.test.result_stream import ResultStream
+from   qm.test.report import ReportGenerator
 from   qm.trace import *
 import qm.test.web.web
 import qm.xmlutil
@@ -286,6 +288,14 @@ class QMTest:
         "Specify the kind of extension class."
         )
 
+    report_output_option_spec = (
+        "o",
+        "output",
+        "FILE",
+        "Write test report to FILE (- for stdout)."
+        )
+
+
     # Groups of options that should not be used together.
     conflicting_option_specs = (
         ( output_option_spec, no_output_option_spec ),
@@ -421,6 +431,16 @@ should not directly invoke QMTest with this option.
          (help_option_spec,)
          ),
 
+        ("report",
+         "Generate report from one or more test results.",
+         "[ result [-e expected] ]+",
+         """
+Generates a test report. The arguments are result files each optionally
+followed by '-e' and an expectation file.
+         """,
+         (help_option_spec, report_output_option_spec)
+         ),
+
         ("run",
          "Run one or more tests.",
          "[ ID ... ]",
@@ -474,7 +494,7 @@ Valid formats are %s.
 
     __version_output = \
         ("QMTest %s\n" 
-         "Copyright (C) 2002, 2003, 2004 CodeSourcery, LLC\n"
+         "Copyright (C) 2002, 2003, 2004, 2005 CodeSourcery, LLC\n"
          "QMTest comes with ABSOLUTELY NO WARRANTY\n"
          "For more information about QMTest visit http://www.qmtest.com\n")
     """The string printed when the --version option is used.
@@ -521,8 +541,6 @@ Valid formats are %s.
         # If available, record the path to the qmtest executable.
         self.__qmtest_path = path
         
-        # We have not yet loaded the database.
-        self.__database = None
         # We have not yet computed the set of available targets.
         self.targets = None
 
@@ -537,6 +555,12 @@ Valid formats are %s.
         self.__expected_outcomes = None
 
 
+    def __del__(self):
+        """Clean up global variables."""
+        
+        test.set_targets([])
+
+
     def HasGlobalOption(self, option):
         """Return true if 'option' was specified as a global command.
 
@@ -628,6 +652,7 @@ Valid formats are %s.
         # Normalize the path so that it is easy for the user to read
         # if it is emitted in an error message.
         self.__db_path = os.path.normpath(db_path)
+        database.set_path(self.__db_path)
 
         error_occurred = 0
         
@@ -643,6 +668,7 @@ Valid formats are %s.
             "register" : self.__ExecuteRegister,
             "remote" : self.__ExecuteRemote,
             "run" : self.__ExecuteRun,
+            "report" : self.__ExecuteReport,
             "summarize": self.__ExecuteSummarize,
             }[self.__command]
 
@@ -652,10 +678,7 @@ Valid formats are %s.
     def GetDatabase(self):
         """Return the test database to use."""
 
-        if not self.__database:
-            self.__database = database.load_database(self.__db_path)
-            
-        return self.__database
+        return database.get_database()
 
 
     def GetTargetFileName(self):
@@ -712,10 +735,10 @@ Valid formats are %s.
 
         returns -- A sequence of 'Target' objects."""
 
-        if self.targets is None:
+        if not test.get_targets():
             file_name = self.GetTargetFileName()
             if os.path.exists(file_name):
-                self.targets = self.GetTargetsFromFile(file_name)
+                test.set_targets(self.GetTargetsFromFile(file_name))
             else:
                 # The target file does not exist.
                 concurrency = self.GetCommandOption("concurrency")
@@ -742,9 +765,9 @@ Valid formats are %s.
                 target_class \
                     = get_extension_class(class_name,
                                           'target', self.GetDatabase())
-                self.targets = [ target_class(self.GetDatabase(), arguments) ]
+                test.set_targets([target_class(self.GetDatabase(), arguments)])
             
-        return self.targets
+        return test.get_targets()
         
 
     def GetTracer(self):
@@ -1062,10 +1085,7 @@ Valid formats are %s.
         class_name = self.__arguments[1]
 
         # Check that the KIND is valid.
-        if kind not in base.extension_kinds:
-            raise qm.cmdline.CommandError, \
-                  qm.error("invalid extension kind",
-                           kind = kind)
+        self.__CheckExtensionKind(kind)
 
         # Check that the CLASS_NAME is well-formed.
         if class_name.count('.') != 1:
@@ -1282,6 +1302,27 @@ Valid formats are %s.
         return 0
 
 
+    def __ExecuteReport(self):
+        """Execute a 'report' command."""
+
+        output = self.GetCommandOption("output")
+
+        # Check that at least one result file is present.
+        if not output or len(self.__arguments) < 1:
+            self.__WriteCommandHelp("report")
+            return 2
+
+        # If the database can be loaded, use it to find all
+        # available tests.
+        try:
+            database = self.GetDatabase()
+        except:
+            database = None
+
+        report_generator = ReportGenerator(output, database)
+        report_generator.GenerateReport(self.__arguments)
+        
+
     def __ExecuteRun(self):
         """Execute a 'run' command."""
         
@@ -1462,6 +1503,9 @@ Valid formats are %s.
                 else:
                     # Other signals propagate outwards.
                     raise
+            except KeyboardInterrupt:
+                # If we receive a keyboard interrupt (Ctrl-C), shut down.
+                pass
         finally:
             if pid_file:
                 os.remove(pid_file_path)
